summaryrefslogtreecommitdiffabout
path: root/kmicromail/libmailwrapper/abstractmail.cpp
Side-by-side diff
Diffstat (limited to 'kmicromail/libmailwrapper/abstractmail.cpp') (more/less context) (ignore whitespace changes)
-rw-r--r--kmicromail/libmailwrapper/abstractmail.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kmicromail/libmailwrapper/abstractmail.cpp b/kmicromail/libmailwrapper/abstractmail.cpp
index 2d7533c..8ee112c 100644
--- a/kmicromail/libmailwrapper/abstractmail.cpp
+++ b/kmicromail/libmailwrapper/abstractmail.cpp
@@ -13,3 +13,3 @@
#include <qmessagebox.h>
-
+#include <klocale.h>
#include <kdecore/kstandarddirs.h>
@@ -149,6 +149,6 @@ void AbstractMail::deleteMailList(const QValueList<RecMailP>&target)
QProgressBar wid ( count );
- wid.setCaption( tr("Deleting ..."));
+ wid.setCaption( i18n("Deleting ..."));
wid.show();
while (iii < count ) {
- Global::statusMessage(tr("Delete message %1 of %2").arg(iii).arg(count));
+ Global::statusMessage(i18n("Delete message %1 of %2").arg(iii).arg(count));
wid.setProgress( iii );
@@ -174,4 +174,4 @@ void AbstractMail::downloadNewMails(const FolderP&fromFolder, AbstractMail*targe
{
- QMessageBox::critical(0,tr("Error creating new Folder"),
- tr("Error while creating new folder\n%1\n\nCancelling action.").arg(lfName));
+ QMessageBox::critical(0,i18n("Error creating new Folder"),
+ i18n("Error while creating new folder\n%1\n\nCancelling action.").arg(lfName));
return;
@@ -182,3 +182,3 @@ void AbstractMail::downloadNewMails(const FolderP&fromFolder, AbstractMail*targe
qDebug("There are no new messages %s", fromFolder->getName().latin1());
- Global::statusMessage(tr("There are no new messages"));
+ Global::statusMessage(i18n("There are no new messages"));
return;
@@ -212,3 +212,3 @@ void AbstractMail::downloadNewMails(const FolderP&fromFolder, AbstractMail*targe
if ( n.count() == 0 ) {
- Global::statusMessage(tr("There are no new messages"));
+ Global::statusMessage(i18n("There are no new messages"));
return;
@@ -216,3 +216,3 @@ void AbstractMail::downloadNewMails(const FolderP&fromFolder, AbstractMail*targe
mvcpMailList( n,lfName,targetMail,!acc->getLeaveOnServer());
- Global::statusMessage(tr("Downloaded %1 messages").arg(n.count()));
+ Global::statusMessage(i18n("Downloaded %1 messages").arg(n.count()));
@@ -242,9 +242,9 @@ void AbstractMail::mvcpMailList(const QValueList<RecMailP>& t,
// wel, processevents is qite strange, we need a widget for getting
// Global::statusMessage(tr("Copy2 message %1").arg(iii)); displaye
QProgressBar wid ( count );
- wid.setCaption( tr("Copying ..."));
+ wid.setCaption( i18n("Copying..."));
wid.show();
while (iii < count ) {
- Global::statusMessage(tr("Copy message %1 of %2").arg(iii).arg(count));
+ Global::statusMessage(i18n("Copy message %1 of %2").arg(iii).arg(count));
wid.setProgress( iii );
@@ -242,9 +242,9 @@ void AbstractMail::mvcpMailList(const QValueList<RecMailP>& t,
// wel, processevents is qite strange, we need a widget for getting
- // Global::statusMessage(tr("Copy2 message %1").arg(iii)); displaye
+ // Global::statusMessage(i18n("Copy2 message %1").arg(iii)); displaye
QProgressBar wid ( count );